cli_util

package
v0.0.0-...-806114d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2024 License: MPL-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConfigData

type ConfigData struct {
	// Environments is a map of available environments keyed by name.
	Environments *map[string]*ops.Environment `mapstructure:"environments"`
	// EnvironmentDefault is a map of available environments keyed by name.
	EnvironmentDefault string `mapstructure:"environment_default,omitempty"`
	// Target is the name of the target environment.
	Target string `mapstructure:"target"`
	// TargetEnv is the target environment to act on.
	TargetEnv *ops.Environment `mapstructure:"-"` // This is not a config value, it's a convenience for the target environment
}

ConfigData is the configuration for the TykOps client.

var Config *ConfigData

Jump to