rest

package
v0.0.0-...-806114d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2024 License: MPL-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var UserAgent = "TykOps/1.x-Dev"

UserAgent is the user agent request header used for all requests. This can be useful in identifying our requests on the server side.

Functions

func InitUserAgent

func InitUserAgent(version string)

InitUserAgent sets the UserAgent variable to the given version.

Types

This section is empty.

Jump to