Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigData ¶
type ConfigData struct {
// Environments is a map of available environments keyed by name.
Environments *map[string]*ops.Environment `mapstructure:"environments"`
// EnvironmentDefault is a map of available environments keyed by name.
EnvironmentDefault string `mapstructure:"environment_default,omitempty"`
// Target is the name of the target environment.
Target string `mapstructure:"target"`
// TargetEnv is the target environment to act on.
TargetEnv *ops.Environment `mapstructure:"-"` // This is not a config value, it's a convenience for the target environment
}
ConfigData is the configuration for the TykOps client.
var Config *ConfigData
Click to show internal directories.
Click to hide internal directories.