Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var UserAgent = "TykOps/1.x-Dev"
UserAgent is the user agent request header used for all requests. This can be useful in identifying our requests on the server side.
Functions ¶
func InitUserAgent ¶
func InitUserAgent(version string)
InitUserAgent sets the UserAgent variable to the given version.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.